@@ -116,8 +116,20 @@ import aws_cdk.aws_cloudfront
 import aws_cdk.core
 
 
-class CloudFrontToApiGateway(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGateway"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi, cloud_front_distribution_props: typing.Any=None, insert_http_security_headers: typing.Optional[bool]=None) -> None:
+class CloudFrontToApiGateway(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGateway",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
+        cloud_front_distribution_props: typing.Any = None,
+        insert_http_security_headers: typing.Optional[bool] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -132,7 +144,11 @@ class CloudFrontToApiGateway(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, js
         summary:
         :summary:: Constructs a new instance of the CloudFrontToApiGateway class.
         """
-        props = CloudFrontToApiGatewayProps(existing_api_gateway_obj=existing_api_gateway_obj, cloud_front_distribution_props=cloud_front_distribution_props, insert_http_security_headers=insert_http_security_headers)
+        props = CloudFrontToApiGatewayProps(
+            existing_api_gateway_obj=existing_api_gateway_obj,
+            cloud_front_distribution_props=cloud_front_distribution_props,
+            insert_http_security_headers=insert_http_security_headers,
+        )
 
         jsii.create(CloudFrontToApiGateway, self, [scope, id, props])
 
@@ -143,13 +159,29 @@ class CloudFrontToApiGateway(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, js
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
-    def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.CloudFrontWebDistribution:
+    def cloud_front_web_distribution(
+        self,
+    ) -> aws_cdk.aws_cloudfront.CloudFrontWebDistribution:
         return jsii.get(self, "cloudFrontWebDistribution")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGatewayProps", jsii_struct_bases=[], name_mapping={'existing_api_gateway_obj': 'existingApiGatewayObj', 'cloud_front_distribution_props': 'cloudFrontDistributionProps', 'insert_http_security_headers': 'insertHttpSecurityHeaders'})
-class CloudFrontToApiGatewayProps():
-    def __init__(self, *, existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi, cloud_front_distribution_props: typing.Any=None, insert_http_security_headers: typing.Optional[bool]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGatewayProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "existing_api_gateway_obj": "existingApiGatewayObj",
+        "cloud_front_distribution_props": "cloudFrontDistributionProps",
+        "insert_http_security_headers": "insertHttpSecurityHeaders",
+    },
+)
+class CloudFrontToApiGatewayProps:
+    def __init__(
+        self,
+        *,
+        existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
+        cloud_front_distribution_props: typing.Any = None,
+        insert_http_security_headers: typing.Optional[bool] = None,
+    ) -> None:
         """
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
@@ -159,10 +191,14 @@ class CloudFrontToApiGatewayProps():
         :summary:: The properties for the CloudFrontToApiGateway Construct
         """
         self._values = {
-            'existing_api_gateway_obj': existing_api_gateway_obj,
+            "existing_api_gateway_obj": existing_api_gateway_obj,
         }
-        if cloud_front_distribution_props is not None: self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
-        if insert_http_security_headers is not None: self._values["insert_http_security_headers"] = insert_http_security_headers
+        if cloud_front_distribution_props is not None:
+            self._values[
+                "cloud_front_distribution_props"
+            ] = cloud_front_distribution_props
+        if insert_http_security_headers is not None:
+            self._values["insert_http_security_headers"] = insert_http_security_headers
 
     @builtins.property
     def existing_api_gateway_obj(self) -> aws_cdk.aws_apigateway.RestApi:
@@ -171,7 +207,7 @@ class CloudFrontToApiGatewayProps():
         default
         :default: - None
         """
-        return self._values.get('existing_api_gateway_obj')
+        return self._values.get("existing_api_gateway_obj")
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -180,7 +216,7 @@ class CloudFrontToApiGatewayProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('cloud_front_distribution_props')
+        return self._values.get("cloud_front_distribution_props")
 
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[bool]:
@@ -189,7 +225,7 @@ class CloudFrontToApiGatewayProps():
         default
         :default: - true
         """
-        return self._values.get('insert_http_security_headers')
+        return self._values.get("insert_http_security_headers")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -198,7 +234,9 @@ class CloudFrontToApiGatewayProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CloudFrontToApiGatewayProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CloudFrontToApiGatewayProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
